Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func UploadPVCToTask ¶
func UploadPVCToTask(t *task.RestoreTask, restoreTarget string, archiveTarget string)
UploadPVCToTask compresses the restored files in the PVC and uploads it to the Lagoon task.
Types ¶
type BootstrapResult ¶
type BootstrapResult struct {
Cleanup func()
// contains filtered or unexported fields
}
func BootstrapUploadPod ¶
func BootstrapUploadPod(t *task.RestoreTask, taskImage string, restoreTarget string, restorePVC *corev1.PersistentVolumeClaim, archiveTarget string) (*BootstrapResult, error)
BootstrapUploadPod creates a new pod with the restore PVC, a PVC to save the archived files, and runs the `upload` sub-subcommand.
type RestoreToPVCResult ¶
type RestoreToPVCResult struct {
PVC *corev1.PersistentVolumeClaim
Restore *k8upv1.Restore
Cleanup func()
}
func RestoreToPVC ¶
func RestoreToPVC(t *task.RestoreTask) (*RestoreToPVCResult, error)
RestoreToPVC creates a PVC and restores a backup to it.
Click to show internal directories.
Click to hide internal directories.